# Changelog

## 1.1.0 (26.03.2023)

* **New**: Added JupyterBook CLI extension

## 1.0.0 (31.01.2023)

* **Breaking**: Removed the OU-XML related functionality
* **New**: Added basic testing
* **New**: Added support for dark mode
* **Update**: Upgrade to sphinx-book-theme >= 1.0
* **Update**: Update styling to closer match brand guidelines

## 0.5.2 (15.08.2023)

* **New**: Add support for cross-references within documents and parts
* **Update**: Update docs - ouxml generation
* **Update**: Minor updates to tag handling (Image/legend)
* **Update**: Update copyright notice in accordance with convention check

## 0.5.1 (29.06.2023)

* **Bugfix**: Fix the OU-XML tag for multi-line code blocks

## 0.5.0 (12.06.2023)

* **New**: Add support for single-part content

## 0.4.0 (30.05.2023)

* **New**: Added a version command to the CLI
* **New**: Ensure external links open in new tabs

## 0.2.2 (18.04.2023)

* **Update**: Various accessibility improvements

## 0.2.1 (08.03.2023)

* **New**: Added sphinxcontrib-mermaid dependency
* **Update**: Updated sphinx-book-theme to >=1.0.0,<2.0.0
